@@ -28,11 +28,11 @@ App::Licensecheck - functions for a simple license checker for source files
 
 =head1 VERSION
 
-Version v3.0.5
+Version v3.0.6
 
 =cut
 
-our $VERSION = version->declare("v3.0.5");
+our $VERSION = version->declare("v3.0.6");
 
 =head1 SYNOPSIS
 
@@ -262,26 +262,22 @@ sub parse_file
 				)
 		}
 	}
-
-	my %copyrights = extract_copyright($content);
-
 	print qq(----- $file content -----\n$content----- end content -----\n\n)
 		if $self->verbose;
 
-	my $license
-		= $self->parse_license(
-		clean_cruft_and_spaces( clean_comments($content) ) );
-	my $copyright = join( " / ", reverse sort values %copyrights );
+	my $cleaned_content = clean_comments($content);
 
-	return ( $license, $copyright );
+	return (
+		$self->parse_license( clean_cruft_and_spaces($cleaned_content) ),
+		extract_copyright($cleaned_content),
+	);
 }
 
 sub parse_lines
 {
-	my $self      = shift;
-	my $file      = path(shift);
-	my $content   = '';
-	my $copyright = '';
+	my $self    = shift;
+	my $file    = path(shift);
+	my $content = '';
 
 	my $fh;
 	my $st = $file->stat;
@@ -301,18 +297,16 @@ sub parse_lines
 		last if ( $fh->input_line_number > $self->lines );
 		$content .= $line;
 	}
-
-	my %copyrights = extract_copyright($content);
-
 	print qq(----- $file header -----\n$content----- end header -----\n\n)
 		if $self->verbose;
 
-	my $license
-		= $self->parse_license(
-		clean_cruft_and_spaces( clean_comments($content) ) );
-	$copyright = join( " / ", reverse sort values %copyrights );
+	my $cleaned_content = clean_comments($content);
 
-	if ( not $copyright and $license eq 'UNKNOWN' ) {
+	my $license
+		= $self->parse_license( clean_cruft_and_spaces($cleaned_content) );
+	my $copyrights = extract_copyright($cleaned_content);
+
+	if ( not @$copyrights and $license eq 'UNKNOWN' ) {
 		my $position = $fh->tell;                 # See IO::Seekable
 		my $jump     = $st->size - $self->tail;
 		$jump = $position if $jump < $position;
@@ -322,27 +316,25 @@ sub parse_lines
 			$fh->seek( $jump, SEEK_SET );         # also IO::Seekable
 			$tail .= join( '', $fh->getlines );
 		}
-
 		print qq(----- $file tail -----\n$tail----- end tail -----\n\n)
 			if $self->verbose;
 
-		%copyrights = extract_copyright($tail);
+		my $cleaned_tail = clean_comments($tail);
+
+		$copyrights = extract_copyright($cleaned_tail);
 		$license
-			= $self->parse_license(
-			clean_cruft_and_spaces( clean_comments($tail) ) );
-		$copyright = join( " / ", reverse sort values %copyrights );
+			= $self->parse_license( clean_cruft_and_spaces($cleaned_tail) );
 	}
 
 	$fh->close;
-	return ( $license, $copyright );
+	return ( $license, $copyrights );
 }
 
 sub extract_copyright
 {
-	my $content = shift;
-	my @c = split /\n/, clean_comments($content);
+	my @c = split /\n/, shift;
 
-	my %copyrights;
+	my @copyrights;
 	my $lines_after_copyright_block = 0;
 
 	my $in_copyright_block = 0;
@@ -357,16 +349,16 @@ sub extract_copyright
 			}
 			$copyright_match =~ s/\s+/ /g;
 			$copyright_match =~ s/\s*$//;
-			$copyrights{ lc("$copyright_match") } = "$copyright_match";
+			push @copyrights, $copyright_match;
 		}
-		elsif ( scalar keys %copyrights ) {
+		elsif (@copyrights) {
 
  # skip remaining lines if a copyright blocks was found more than 5 lines ago.
  # so a copyright block may contain up to 5 blank lines, but no more
 			last if $lines_after_copyright_block++ > 5;
 		}
 	}
-	return %copyrights;
+	return \@copyrights;
 }
 
 sub parse_copyright
